==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/winamp_mediaplayer/winamp-player-plugin.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
 * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
 * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
 * Copyright 2007, 2009, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
 * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "plugins/mediaplayer/mediaplayer.h"

#include "winamp-player-plugin.h"
#include "winamp.h"

WinampMediaplayerPlugin::~WinampMediaplayerPlugin()
{
}

int WinampMediaplayerPlugin::init(bool firstLoad)
{
	Q_UNUSED(firstLoad)
	PlayerInstance = new WinampMediaPlayer();
	bool res = MediaPlayer::instance()->registerMediaPlayer(PlayerInstance, PlayerInstance);
	return res ? 0 : 1;
}

void WinampMediaplayerPlugin::done()
{
	MediaPlayer::instance()->unregisterMediaPlayer();
	delete PlayerInstance;
	PlayerInstance = 0;
}

Q_EXPORT_PLUGIN2(winamp_mediaplayer, WinampMediaplayerPlugin)

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/winamp_mediaplayer/winamp-player-plugin.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2011 Sławomir Stępień (s.stepien@interia.pl)
 * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
 * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
 * Copyright 2007, 2009, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
 * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "plugins/mediaplayer/mediaplayer.h"

#include "winamp-player-plugin.h"
#include "winamp.h"

WinampMediaplayerPlugin::~WinampMediaplayerPlugin()
{
}

bool WinampMediaplayerPlugin::init(bool firstLoad)
{
	Q_UNUSED(firstLoad)
	PlayerInstance = new WinampMediaPlayer();
	return MediaPlayer::instance()->registerMediaPlayer(PlayerInstance, PlayerInstance);
}

void WinampMediaplayerPlugin::done()
{
	MediaPlayer::instance()->unregisterMediaPlayer();
	delete PlayerInstance;
	PlayerInstance = 0;
}

Q_EXPORT_PLUGIN2(winamp_mediaplayer, WinampMediaplayerPlugin)

#include "moc_winamp-player-plugin.cpp"
